@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2016-2018 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2016-2022 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of pdf2djvu.
 #
@@ -27,7 +27,7 @@ expected_outline_sexpr = ('''\
  ("Lorem"
   "#p0001.djvu"
 '''
-+ '\n'.join(item_template.format(i) for i in range(0, b))
++ str.join('\n', (item_template.format(i) for i in range(0, b)))
 + ' ) )\n'
 )
 
